@@ -1,5 +1,5 @@
 package Convert::Z85;
-$Convert::Z85::VERSION = '0.001002';
+$Convert::Z85::VERSION = '0.002001';
 use Carp;
 use strictures 1;
 
@@ -19,11 +19,16 @@ my @chrs = split '',
 
 my %intforchr = map {; $chrs[$_] => $_ } 0 .. $#chrs;
 
-my @offsets = reverse map {; 85 ** $_ } 0 .. 4;
+my @multiples = reverse map {; 85 ** $_ } 0 .. 4;
 
 sub encode_z85 {
-  my $bin = shift;
-  my $len = bytes::length($bin);
+  my ($bin, %param) = @_;
+
+  my $len = bytes::length($bin) || return '';
+  if ($param{pad}) {
+    $bin .= "\0" x (-$len % 4);
+    $len = bytes::length($bin);
+  }
   croak "Expected data padded to 4-byte chunks; got length $len" if $len % 4;
 
   my $chunks = $len / 4;
@@ -31,29 +36,28 @@ sub encode_z85 {
   
   my $str;
   for my $val (@values) {
-    for my $offset (@offsets) {
-      $str .= $chrs[ ( int($val / $offset) ) % 85 ]
-    }
+    $str .= $chrs[ ( int($val / $_) ) % 85 ] for @multiples;
   }
   
   $str
 }
 
 sub decode_z85 {
-  my $txt = shift;
-  my $len = length $txt;
-  croak "Expected Z85 text in 5 byte chunks; got length $len" if $len % 5;
+  my ($txt, %param) = @_;
+  my $len = length $txt || return '';
+
+  croak "Expected Z85 text in 5-byte chunks; got length $len" if $len % 5;
 
   my @values;
   for my $idx (grep {; not($_ % 5) } 0 .. $len) {
     my ($val, $cnt) = (0, 0);
 
-    for my $offset (@offsets) {
+    for my $mult (@multiples) {
       my $chr = substr $txt, ($idx + $cnt), 1;
       last unless length $chr;
       croak "Invalid Z85 input; '$chr' not recognized"
         unless exists $intforchr{$chr};
-      $val += $intforchr{$chr} * $offset;
+      $val += $intforchr{$chr} * $mult;
       ++$cnt;
     }
 
@@ -61,7 +65,9 @@ sub decode_z85 {
   }
 
   my $chunks = $len / 5;
-  pack "(N)$chunks", @values
+  my $ret = pack "(N)$chunks", @values;
+  $ret =~ s/\0{0,3}$// if $param{pad};
+  $ret
 }
 
 
@@ -89,26 +95,32 @@ plain text.
 Modelled on the L<PyZMQ|http://zeromq.github.io/pyzmq/> implementation.
 
 This module uses L<Exporter::Tiny> to export two functions by default:
-L</encode_z85> and L</decode_z85>. L<Exporter::Tiny> provides flexible import
-options; look there for details.
+L</encode_z85> and L</decode_z85>.
 
 =head2 encode_z85
 
-  encode_z85($data);
+  my $z85 = encode_z85($data);
 
-Takes binary data (in 4-byte chunks padded with trailing zero bytes if
-necessary) and returns a Z85-encoded text string.
+Takes binary data in 4-byte chunks and returns a Z85-encoded text string.
 
-Padding is left up to the application, per the spec.
+Per the spec, padding is not performed automatically; the B<pad> option can be
+specified to pad data with trailing zero bytes:
+
+  my $z85 = encode_z85($data, pad => 1);
 
 =head2 decode_z85
 
-  decode_z85($encoded);
+  my $bin = decode_z85($encoded);
 
 Takes a Z85 text string and returns the original binary data.
 
 Throws a stack trace if invalid data is encountered.
 
+Per the spec, removing padding is not performed automatically; the B<pad>
+option can be specified to remove trailing zero bytes:
+
+  my $bin = decode_z85($encoded, pad => 1);
+
 =head1 SEE ALSO
 
 L<Convert::Ascii85>
